

A metadata plugin for isbnlib (https://pypi.python.org/pypi/isbnlib) using the service BnF Catalogue Général (for books in french).

After install, a new metadata provider (bnf) is available in isbnlib.

